function [ A, b, c, K, info] = makeMatComp( n, m, r)
%MAKEMATCOMP Low-rank Rectangular matrix completion
% The problem
%   minimize trace(Z)
%   s.t.     Xij = Aij for all {i,j} in S
%            Z   = [ U, X'] 
%                  [ X, V ] >= 0
% often produces a low-rank solution when the number of measurements in S
% is large and selected uniformly

if nargin < 3 || isempty(r)
    r = 1; % default to rank-1
end

% Problem dimension
switch numel(n)
    case 1
        n1 = n; n2 = n;
    case 2
        n1 = n(1); n2 = n(2);
    otherwise
        error('wrong dimension in "n"');
end
N = n1+n2;

% Select m random measurements
Omega = randperm(n1*n2, m); % row
[sel1, sel2] = ind2sub([n1,n2],Omega);
idx1 = sub2ind([N,N], sel1 + n2, sel2); % lower-right
idx2 = sub2ind([N,N], sel2, sel1 + n2); % upper-left
A = sparse([idx1,idx2],[1:m,1:m],0.5, N^2, m, 2*m);

% Generate a random solution
x = randn(N,r); X = x*x';
b = A'*X(:);

% Output trace
c = eye(N); 
c = c(:);

% Cone
K = struct;
K.l = 0;
K.s = N;

% Info on the problem
info.M = x(n2+1:end,:)*x(1:n2,:)';
info.Omega = Omega(:);
info.screen = false(N,N); % Screen the SDP solution to recover the matrix.
info.screen(n2+1:end, 1:n2) = true;
info.screen = info.screen(:);
info.x = x; % Rank-r solution

end